@@ -1,5 +1,5 @@
 /* This file is part of YAZ proxy
-   Copyright (C) 1998-2009 Index Data
+   Copyright (C) 1998-2011 Index Data
 
 YAZ proxy is free software; you can redistribute it and/or modify it under
 the terms of the GNU General Public License as published by the Free
@@ -26,6 +26,7 @@ Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
 #if HAVE_USEMARCON
 #include <usemarconlib.h>
+#include <defines.h>
 #endif
 
 #include <yazpp/record-cache.h>
@@ -59,6 +60,7 @@ public:
     const char *get_client_query_charset(void);
     const char *get_target_query_charset(void);
     void convert_type_1(Z_RPNQuery *q, ODR o);
+    void convert_term(Z_Term *q, ODR o);
     void set_client_charset_selected(int sel);
     int get_client_charset_selected();
 private:
